@@ -15,14 +15,14 @@ class MichelineSchemaError(ValueError):
 
 
 def build_schema(code) -> Schema:
-    """
-    Creates internal structures necessary for decoding/encoding micheline:
+    """ Creates internal structures necessary for decoding/encoding micheline:
     `metadata` -> micheline tree with collapsed `pair`, `or`, and `option` nodes
     `bin_types` -> maps binary path to primitive
     `bin_names` -> binary path to key name mapping
     `json_to_bin` -> json path to binary path mapping
+
     :param code: parameter or storage section of smart contract source code (in micheline)
-    :return: Schema
+    :rtype: Schema
     """
     try:
         metadata = collapse_micheline(code)
@@ -33,13 +33,13 @@ def build_schema(code) -> Schema:
 
 
 def decode_micheline(val_expr, type_expr, schema: Schema, root='0'):
-    """
-    Converts Micheline data into Python object
+    """ Converts Micheline data into Python object.
+
     :param val_expr: Micheline value expression
     :param type_expr: Michelson type expression for the entire type
     :param schema: schema built for particular contract/section
     :param root: which binary node to take as root, used to decode BigMap values/diffs
-    :return: Object
+    :returns: Object
     """
     try:
         return parse_micheline(val_expr, type_expr, schema, root)
@@ -50,13 +50,13 @@ def decode_micheline(val_expr, type_expr, schema: Schema, root='0'):
 
 
 def encode_micheline(data, schema: Schema, root='0', binary=False):
-    """
-    Converts Python object into Micheline expression
+    """ Converts Python object into Micheline expression.
+
     :param data: Python object
     :param schema: schema built for particular contract/section
     :param root: which binary node to take as root, used to encode BigMap values
     :param binary: Encode keys and addresses in bytes rather than strings, default is False
-    :return: Micheline expression
+    :returns: Micheline expression
     """
     try:
         bin_values = parse_json(data, schema, root)
@@ -68,8 +68,8 @@ def encode_micheline(data, schema: Schema, root='0', binary=False):
 
 
 def convert(source, schema: Schema = None, output='micheline', inline=False):
-    """
-    Convert data between different representations (DO NOT USE FOR STORAGE/PARAMETER, can be ambiguous)
+    """ Convert data between different representations (DO NOT USE FOR STORAGE/PARAMETER, can be ambiguous).
+
     :param source: Data, can be one of Michelson (string), Micheline expression, object
     :param schema: Needed if decoding/encoding objects (optional)
     :param output: Output format, one of 'micheline' (default), 'michelson', 'object'
@@ -96,6 +96,13 @@ def convert(source, schema: Schema = None, output='micheline', inline=False):
 
 
 def build_big_map_schema(data, schema: Schema) -> BigMapSchema:
+    """ Generate Big_map schema from the contract storage
+
+    :param data: Raw storage (Micheline expression)
+    :param schema: Storage schema
+    :returns: Mappings: Big_map id to JSON path and vice versa
+    :rtype: BigMapSchema
+    """
     bin_to_id = dict()
     id_to_bin = dict()
 
@@ -118,7 +125,12 @@ def build_big_map_schema(data, schema: Schema) -> BigMapSchema:
     return BigMapSchema(bin_to_id, id_to_bin)
 
 
-def is_micheline(value):
+def is_micheline(value) -> bool:
+    """ Check if value is a Micheline expression (using heuristics, so not 100% accurate).
+
+    :param value: Object
+    :rtype: bool
+    """
     if isinstance(value, list):
         def get_prim(x):
             return x.get('prim') if isinstance(x, dict) else None
